@@ -14,6 +14,7 @@ sub irc_nick () { POE::Kernel->alias_resolve('irc_session')->get_heap->{irc}->ni
 sub render_td {
     my ($c, @args) = @_;
     my $html = App::Mobirc::Web::View->show(@args);
+    _set_content_type($c);
     _make_response($c, $html);
 }
 
@@ -21,24 +22,32 @@ sub _make_response {
     my ( $c, $out ) = @_;
 
     ($c, $out) = context->run_hook_filter('html_filter', $c, $out);
-    my $content = encode( $c->req->mobile_agent->encoding, $out);
+    $out = encode( $c->req->mobile_agent->encoding, $out);
 
-    # change content type for docomo
-    # FIXME: hmm... should be in the plugin?
-    my $content_type = context->config->{httpd}->{content_type};
-    $content_type= 'application/xhtml+xml' if $c->req->mobile_agent->is_docomo;
-    unless ( $content_type ) {
-        if ( $c->req->mobile_agent->can_display_utf8 ) {
-            $content_type = 'text/html; charset=UTF-8';
-        } else {
-            $content_type = 'text/html; charset=Shift_JIS';
-        }
-    }
-
-    $c->res->content_type(encode('utf8', $content_type));
-    $c->res->body( $content );
+    $c->res->body( $out );
 
     context->run_hook('response_filter', $c);
 }
 
+sub _set_content_type {
+    my $c = shift;
+
+    my $content_type = do {
+        if ( $c->req->mobile_agent->is_docomo ) {
+            # docomo phone cannot apply css without this content_type
+            'application/xhtml+xml';
+        }
+        else {
+            if ( $c->req->mobile_agent->can_display_utf8 ) {
+                'text/html; charset=UTF-8';
+            }
+            else {
+                'text/html; charset=Shift_JIS';
+            }
+        }
+    };
+
+    $c->res->content_type(encode('utf8', $content_type));
+}
+
 1;
