@@ -2,10 +2,13 @@ package App::Mobirc::Web::Handler;
 use Moose;
 use Scalar::Util qw/blessed/;
 use Data::Visitor::Encode;
+use HTTP::MobileAgent;
+use HTTP::MobileAgent::Plugin::Charset;
+use Module::Find;
+
 use App::Mobirc;
 use App::Mobirc::Util;
 use App::Mobirc::Web::Router;
-use Module::Find;
 useall 'App::Mobirc::Web::C';
 
 my $dve = Data::Visitor::Encode->new;
@@ -54,9 +57,9 @@ sub process_request {
             my $uri = $c->req->uri->path;
             warn "dan the 404 not found: $uri" if $uri ne '/favicon.ico';
             # TODO: use $c->res->status(404)
-            my $response = HTTP::Response->new(404);
-            $response->content("Dan the 404 not found: $uri");
-            return $response;
+            $c->res->status(404);
+            $c->res->body("Dan the 404 not found: $uri");
+            return;
         };
     }
 
